<?php
// THEME OPTIONS: Scrapbook

// Set default options up
function scrapbook_all_theme_options() {
	$all_scrapbook_theme_options = array(
		'thickbox' => array(
			'legend' => __('Enable Thickbox on image pages','scrapbook'),
			'description' => __('Select "No" if you intend to use a lightbox or shadowbox plugin.', 'scrapbook'),
			'type' => 'radio',
			'default' => 'yes',
			'choices' => array(
				'1' => array(
					'value' => 'yes',
					'label' => __( 'Yes', 'scrapbook' )
				),
				'2' => array(
					'value' => 'no',
					'label' => __( 'No', 'scrapbook' )
				)
			)
		),
		'exif_display' => array(
			'legend' => __('Display EXIF data on image pages','scrapbook'),
			'description' => __('Data stored in photographs such as camera, aperture, focal length etc.', 'scrapbook'),
			'type' => 'radio',
			'default' => 'yes',
			'choices' => array(
				'1' => array(
					'value' => 'yes',
					'label' => __( 'Yes', 'scrapbook' )
				),
				'2' => array(
					'value' => 'no',
					'label' => __( 'No', 'scrapbook' )
				)
			)
		)
	);
	return apply_filters( 'scrapbook_default_theme_options', $all_scrapbook_theme_options );
}

// White list theme options
function scrapbook_theme_options_init() {
	register_setting(
		'scrapbook_options',
		'scrapbook_theme_options',
		'scrapbook_theme_options_validate'
	);
}
add_action( 'admin_init', 'scrapbook_theme_options_init' );

// Add theme options page
function scrapbook_theme_options_add_page() {
	$theme_page = add_theme_page(
		__( 'Theme Options', 'scrapbook' ),  // page title
		__( 'Theme Options', 'scrapbook' ), // menu label
		'edit_theme_options', // capability
		'theme_options', // menu slug
		'scrapbook_theme_options_do_page' // page display
	);
	if ( ! $theme_page ) 	return;
	add_action( "load-$theme_page", 'scrapbook_theme_options_help' );
}
add_action('admin_menu', 'scrapbook_theme_options_add_page');

function scrapbook_enqueue_theme_options_style() {
	wp_enqueue_style('theme_options_style', get_template_directory_uri() . '/library/theme-options.css', '', false, 'screen');
}
add_action('admin_print_styles-appearance_page_theme_options', 'scrapbook_enqueue_theme_options_style');

// Theme options form
function scrapbook_theme_options_do_page() {
	$all_scrapbook_theme_options = scrapbook_all_theme_options();
	if ( ! isset( $_REQUEST['updated'] ) ) $_REQUEST['updated'] = false;
	?>

	<div class="wrap">
	<?php screen_icon(); echo "<h2>" . wp_get_theme() . __( ' Options', 'scrapbook') . "</h2>"; ?>

	<?php if ( false !== $_REQUEST['updated'] ) : ?>
	<div class="updated fade"><p><strong><?php _e( 'Your theme options have been saved', 'scrapbook'); ?></strong></p></div>
	<?php endif; ?>

	<?php include_once 'donate.php';?>

	<form method="post" action="options.php" id="scrapbook_options"><div>
	<?php settings_fields( 'scrapbook_options' ); ?>
	<?php $stored_options = get_option('scrapbook_theme_options');?>

	<?php $option_name = 'thickbox';
	scrapbook_theme_options_do_radio( $option_name, $all_scrapbook_theme_options[$option_name], $stored_options );?>

	<?php $option_name = 'exif_display';
	scrapbook_theme_options_do_radio( $option_name, $all_scrapbook_theme_options[$option_name], $stored_options );?>

	<p class="submit"><input type="submit" class="button-primary" value="<?php _e('Update Theme', 'scrapbook') ?>" /></p>

	</div></form>
</div>
	<?php
}

// Radio button display
function scrapbook_theme_options_do_radio($option_name, $option, $stored_options ) {
	if ( !isset( $stored_options[$option_name] ) ) $stored_options[$option_name] = $option['default'];?>

	<fieldset>
	<legend><?php echo esc_attr( $option['legend'] ); ?></legend>
	<label for="<?php echo esc_attr( $option_name );?>_<?php echo esc_attr( $option['default'] ); ?>"><small><?php echo esc_attr( $option['description'] ); ?></small></label><br />

	<?php foreach ( $option['choices'] as $option ) {?>
		<label class="description radio" for="<?php echo $option_name;?>_<?php echo esc_attr( $option['value'] ); ?>"><input type="radio" id="<?php echo $option_name;?>_<?php echo esc_attr( $option['value'] ); ?>" name="scrapbook_theme_options[<?php echo $option_name;?>]" value="<?php echo esc_attr( $option['value'] ); ?>" <?php checked( $stored_options[$option_name] , $option['value'] ); ?> /> <?php echo $option['label']; ?></label><?php
	}?>
	</fieldset>
	<?php
}

// Sanitize and validate inputs
function scrapbook_theme_options_validate( $input ) {
	$new_input = array();
	$all_scrapbook_theme_options = scrapbook_all_theme_options();
	$theme_option_names = array_keys($all_scrapbook_theme_options);

	foreach($theme_option_names as $theme_option_name) {
		$option_type = $all_scrapbook_theme_options[$theme_option_name]['type'];
		if( !isset( $input[$theme_option_name] ) ) $new_input[$theme_option_name] = $all_scrapbook_theme_options[$theme_option_name]['default'];
		switch ($option_type) {

			case 'radio':
			// Default = yes
			if( $all_scrapbook_theme_options[$theme_option_name]['default'] == 'yes' ) $new_input[$theme_option_name] = ( $input[$theme_option_name] == 'yes' ? 'yes' : 'no' );

			default:
			$new_input[$theme_option_name] = $input[$theme_option_name];
		}
	}
	return $new_input;
}

/* THEME CUSTOMIZER */

// Add theme options to Customizer
function scrapbook_customize_register($wp_customize) {
	$all_scrapbook_theme_options = scrapbook_all_theme_options();

	 //Add section
	$wp_customize->add_section( 'scrapbook_options', array(
		'title' => __( 'Scrapbook Options', 'scrapbook' ),
		'description' => __( 'Testing descriptions', 'scrapbook' ),
		'priority'       => 200,
	) );

	foreach( $all_scrapbook_theme_options as $option_key => $option_values ) {
		// Add settings
		$option_name = 'scrapbook_theme_options[' . $option_key . ']';
		$wp_customize->add_setting( $option_name, array(
			'default' => $option_values['default'],
			'type'  => 'option',
			'capability' => 'edit_theme_options',
		) );

		// Add controls
		$choices = array();
		foreach( $option_values['choices'] as $option ) {
			$ckey = $option['value'];
			$cvalue = $option['label'];
			$choices[ $ckey ] = $cvalue;
		}
		$wp_customize->add_control( $option_name, array(
			'label' => $option_values['legend'],
			'section' => 'scrapbook_options',
			'settings' => $option_name,
			'type' => 'radio',
			'choices' => $choices,
		) );
	}

}
add_action( 'customize_register', 'scrapbook_customize_register' );

function scrapbook_theme_options_help() {
	$help = '<p>' . __( 'Some themes provide customization options that are grouped together on a Theme Options screen. If you change themes, options may change or disappear, as they are theme-specific. Your current theme, Scrapbook, provides the following Theme Options:', 'scrapbook' ) . '</p>' .
			'<ol>' .
				'<li>' . __( '<strong>Enable Thickbox </strong>: You can enable the WordPress core lightbox on image attachment pages. Select "No" if you intend to use another lightbox or shadowbox plugin.', 'scrapbook' ) . '</li>' .
				'<li>' . __( '<strong>Display EXIF data</strong>: Almost all digital cameras save JPEG files with EXIF (Exchangeable Image File) data.  Examples of stored information include the timestamp for a photo, aperture, focal length, ISO and shutter speed. Some images may also include copyright information and credits. If you select "Yes", the theme will display any stored EXIF data on the image attachment pages. ', 'scrapbook' ) . '</li>' .
			'</ol>' .
			'<p>' . __( 'Remember to click "Save Changes" to save any changes you have made to the theme options.', 'scrapbook' ) . '</p>';

	$sidebar = '<p><strong>' . __( 'For more information:', 'scrapbook' ) . '</strong></p>' .
		'<p>' . __( '<a href="http://codex.wordpress.org/Appearance_Theme_Options_Screen" target="_blank">Documentation on Theme Options</a>', 'scrapbook' ) . '</p>' .
		'<p>' . __( '<a href="http://forum.quirm.net/" target="_blank">Scrapbook Support</a>', 'scrapbook' ) . '</p>';

	$screen = get_current_screen();

	if ( method_exists( $screen, 'add_help_tab' ) ) {
		// WordPress 3.3
		$screen->add_help_tab( array(
			'title' => __( 'Overview', 'scrapbook' ),
			'id' => 'theme-options-help',
			'content' => $help,
			)
		);
		$screen->set_help_sidebar( $sidebar );
	}
}

